@@ -489,6 +489,39 @@ void MainWindow::makeFdi()
     }
     file.write(FDI_TRLR);
 }
+void MainWindow::setInternalXkbMap()
+{
+
+    FILE * fp=popen(QString("hildon-im-xkbtool --list | grep \"omap_twl4030keypad\"").toLatin1(),"r");
+    if(fp)
+    {
+	QTextStream device_stream( fp, QIODevice::ReadOnly );
+	QString device = device_stream.readLine();
+
+	if((!device.isNull()) && (!device.isEmpty()))
+	{
+	    QString int_kb_model=QGtkStyle::getGConfString("/apps/osso/inputmethod/int_kb_model");
+	    QString int_kb_layout=QGtkStyle::getGConfString("/apps/osso/inputmethod/int_kb_layout");
+	    QString device_id=device.split(",").value(0).split(" ").value(1);
+	    qDebug()<<QString("setxkbmap -device \"%1\" -model \"%2\" -layout \"%3\"").arg(device_id).arg(int_kb_model).arg(int_kb_layout).toLatin1();
+	    system(QString("setxkbmap -device \"%1\" -model \"%2\" -layout \"%3\" -synch").arg(device_id).arg(int_kb_model).arg(int_kb_layout).toLatin1());
+	}
+	else
+	{
+	    QMaemo5InformationBox::information(this, QString("omap_twl4030keypad not found, is this N900?"),
+						QMaemo5InformationBox::NoTimeout);
+	    return;
+	}
+    }
+    else
+	QMaemo5InformationBox::information(this, QString("hildon-im-xkbtool error %1<br>%2").arg(errno).arg(strerror(errno)),
+					    QMaemo5InformationBox::NoTimeout);
+    QApplication::processEvents();
+    //system("setxkbmap");
+    //QApplication::processEvents();
+
+
+}
 
 bool MainWindow::setXkbMap(const QString & product,const QString & model,const QString & layout, const QString & options)
 {
@@ -516,9 +549,10 @@ bool MainWindow::setXkbMap(const QString & product,const QString & model,const Q
 	    QApplication::processEvents();
 
 	    system("setxkbmap");
-	    QApplication::processEvents();
 	}
 
+	QApplication::processEvents();
+
 	pclose(fp);
     }
     else
@@ -541,6 +575,7 @@ void MainWindow::on_buttonBox_accepted()
     QApplication::processEvents();
     system("sudo /usr/libexec/extkbd-set");
     QApplication::processEvents();
+    setInternalXkbMap();
 
     accept();
 }
